Name
You must supply an volume name.
That doesn't look like a valid volume name.
Too long volume name.
Description
Please do not input invalid characters!
Please input the description less than 255 characters.
Rules
Direction ingress egress Ethertype IPv4 IPv6 Protocol TCP UDP ICMP Remote Mode remote_ip_prefix remote_group_id
Port Range Min Port Range Max Remote IP Prefix
It doesn't looks like a valid IP prefix!
Remote Group ID